@@ -9,7 +9,7 @@ from operator import itemgetter
 
 import getpass
 
-__version__ = '0.6.1'
+__version__ = '0.6.2'
 
 
 class Storm(object):
@@ -34,6 +34,7 @@ class Storm(object):
             raise StormValueError('{0} doesn\'t exists in your sshconfig. use storm add command to add.'.format(name))
 
         options = self.get_options(host, user, port, id_file, custom_options)
+
         self.ssh_config.update_host(name, options)
         self.ssh_config.write_to_ssh_config()
 
@@ -69,7 +70,6 @@ class Storm(object):
 
         if order:
             config_data = sorted(config_data, key=itemgetter("host"))
-
         return config_data
 
     def delete_all_entries(self):
@@ -105,10 +105,11 @@ class Storm(object):
         if len(custom_options) > 0:
             for custom_option in custom_options:
                 if '=' in custom_option:
-                    key, value = custom_option.split("=")[0:2]
-                options.update({
-                    key: value,
-                })
+                    key, value = custom_option.split("=")
+
+                    options.update({
+                        key: value,
+                    })
 
         return options
 
