@@ -5,6 +5,12 @@ from __future__ import print_function
 
 import sys
 
+
+try:
+    import __builtin__ as builtins
+except ImportError:
+    import builtins
+
 import getpass
 import collections
 
@@ -101,23 +107,16 @@ def update(name, connection_uri="", id_file="", o=[]):
     """
     Enhanced version of the edit command featuring multiple edits using regular expressions to match entries
     """
+    settings = {}
+
+    if id_file != "": 
+        settings['identityfile'] = id_file
+
+    for option in o:
+        k,v = option.split("=")
+        settings[k] = v
+
     try:
-        user, host, port = parse(connection_uri)
-
-        settings = {}
-        settings.setdefault('port', port)
-        settings.setdefault('user', user)
-        
-        if host != "":
-            settings['hostname'] = host
-
-        if id_file != "": 
-            settings['identityfile'] = id_file
-
-        for option in o:
-            k,v = option.split("=")
-            settings[k] = v
-
         storm_.update_entry(name, **settings)
         print(get_formatted_message(
             '"{0}" updated successfully.'.format(
@@ -166,8 +165,9 @@ def list():
                             extra = True
 
                             if isinstance(value, collections.Sequence):
-                                value = ",".join(value)
-
+                                if isinstance(value, builtins.list):
+                                    value = ",".join(value)
+                                    
                             result += "{0}={1} ".format(key, value)
                     if extra:
                         result = result[0:-1]
