@@ -149,7 +149,7 @@ class prog(object):
             args = list(args)
             is_positional = isinstance(v, self._POSITIONAL)
             options = [arg for arg in args if arg.startswith('-')]
-            if isinstance(v, collections.Sequence):
+            if isinstance(v, list):
                 kwargs.update({
                     'action': 'append',
                 })
