@@ -1,9 +1,9 @@
-# -*- coding: utf8 -*-
+# -*- coding: utf-8 -*-
 
 import getpass
 import re
 
-from exceptions import StormInvalidPortError
+from .exceptions import StormInvalidPortError
 
 
 def parse(uri, user=None, port=22):
@@ -47,6 +47,3 @@ def parse(uri, user=None, port=22):
         host,
         port,
     )
-
-
-
